import React, { useState } from 'react';
import { Transition } from 'react-transition-group';
import PropTypes from 'prop-types';
import { MAXIMUM_DROPDOWN_HEIGHT } from './constants';
import MenuItem from './MenuItem';

const Menu = (props) => {
  const [_menu, setMenu] = useState(null);
  const {
    maxHeight, options, selected, activeIndex, open, loading,
    labelKey, onEntering, onExit, onExiting, onEnter, isDirty,
    style, menuRef, selectItem, autoScroll, disableAutoScroll
  } = props;
  const isSelected = option => {
    const _selected = [...selected].shift();
    return _selected && option[labelKey] === _selected[labelKey]
  };
  const { dropup, ...menuPositionStyle } = style;
  const handleMenuScroll = () => {
    disableAutoScroll();
  }
  return (
    <Transition
      in={open}
      timeout={200}
      appear
      onEntering={onEntering}
      onEntered={onEnter}
      onExiting={onExiting}
      onExited={onExit}
    >
      {
        (status) => {
          return (
            <div
              className={
                `pk-select--dropdown slide-${status}`
              }
              style={{ ...menuPositionStyle }}
              ref={menuRef}
            >
              <div className={`pk-select--transition ${dropup ? 'dropup' : 'dropdown'}`}>
                <div className={`pk-select--popup${open ? ' has-shadow' : ''}`} style={{ maxHeight }} ref={setMenu} onScroll={handleMenuScroll}>
                  {
                    loading ?
                      <div className='pk-select--dropdown_item item-disabled'>Searching...</div>
                      :
                      options.length === 0 ?
                        <div className='pk-select--dropdown_item item-disabled'>
                          {
                            isDirty ? 'No result found' : 'Type to search...'
                          }
                        </div>
                        :
                        options.map((option, i) => (
                          <MenuItem
                            key={option[labelKey]}
                            label={option[labelKey]}
                            activeIndex={activeIndex}
                            position={i}
                            selected={isSelected(option)}
                            menuContainer={_menu}
                            onItemClick={() => selectItem(option, i)}
                            autoScroll={autoScroll}
                          />
                        ))
                  }
                </div>
              </div>
            </div>
          )
        }
      }
    </Transition>
  )
};

Menu.propTypes = {
  options: PropTypes.array.isRequired,
  items: PropTypes.array.isRequired,
  selected: PropTypes.array.isRequired,
  activeIndex: PropTypes.number,
  open: PropTypes.bool,
  onExit: PropTypes.func,
  onExiting: PropTypes.func,
  onEnter: PropTypes.func,
  onEntering: PropTypes.func,
  maxHeight: PropTypes.number,
  style: PropTypes.object,
  menuRef: PropTypes.func,
  selectItem: PropTypes.func,
  autoScroll: PropTypes.bool,
  disableAutoScroll: PropTypes.func,
  loading: PropTypes.bool,
  isDirty: PropTypes.bool,
};

Menu.defaultProps = {
  options: [],
  items: [],
  selected: [],
  activeIndex: -1,
  open: false,
  onExiting: () => { },
  onExit: () => { },
  onEntering: () => { },
  onEnter: () => { },
  maxHeight: MAXIMUM_DROPDOWN_HEIGHT,
  style: {},
  menuRef: () => { },
  selectItem: () => { },
  autoScroll: false,
  disableAutoScroll: () => { },
  loading: false,
  isDirty: false,
};

export default Menu;