import React, { useEffect, useState, forwardRef } from 'react';
import useDebounce from './extras/use-debounce';

const SearchBar = forwardRef(({ onChange = () => { }, value, ...inputProps }, ref) => {
  const [searchQuery, setSearchQuery] = useState(value);

  const debouncedSearchQuery = useDebounce(searchQuery, 300);

  useEffect(
    () => {
      onChange(debouncedSearchQuery);
    },
    [debouncedSearchQuery], // Only call effect if debounced search term changes
  );
  return (
    <input
      {...inputProps}
      onChange={e => setSearchQuery(e.target.value)}
      value={searchQuery}
      ref={ref}
    />
  );
});

export default SearchBar;
